==> aspose-words-cloud-20.6.0.tar.gz: aspose-words-cloud-20.6.0/asposewordscloud/models/split_document_response.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="split_document_response.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six


class SplitDocumentResponse(object):
    """This response should be returned by the service when handling:  POST /{name}/split .
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'split_result': 'SplitDocumentResult'
    }

    attribute_map = {
        'request_id': 'RequestId',
        'split_result': 'SplitResult'
    }

    def __init__(self, request_id=None, split_result=None):  # noqa: E501
        """SplitDocumentResponse - a model defined in Swagger"""  # noqa: E501

        self._request_id = None
        self._split_result = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if split_result is not None:
            self.split_result = split_result

    @property
    def request_id(self):
        """Gets the request_id of this SplitDocumentResponse.  # noqa: E501

        Gets or sets request Id.  # noqa: E501

        :return: The request_id of this SplitDocumentResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this SplitDocumentResponse.

        Gets or sets request Id.  # noqa: E501

        :param request_id: The request_id of this SplitDocumentResponse.  # noqa: E501
        :type: str
        """
        self._request_id = request_id

    @property
    def split_result(self):
        """Gets the split_result of this SplitDocumentResponse.  # noqa: E501

        Gets or sets resylt of splitting document.  # noqa: E501

        :return: The split_result of this SplitDocumentResponse.  # noqa: E501
        :rtype: SplitDocumentResult
        """
        return self._split_result

    @split_result.setter
    def split_result(self, split_result):
        """Sets the split_result of this SplitDocumentResponse.

        Gets or sets resylt of splitting document.  # noqa: E501

        :param split_result: The split_result of this SplitDocumentResponse.  # noqa: E501
        :type: SplitDocumentResult
        """
        self._split_result = split_result


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SplitDocumentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> aspose-words-cloud-20.10.0.tar.gz: aspose-words-cloud-20.10.0/asposewordscloud/models/split_document_response.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="split_document_response.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six
import json


class SplitDocumentResponse(object):
    """This response should be returned by the service when handling:  POST /{name}/split .
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'split_result': 'SplitDocumentResult'
    }

    attribute_map = {
        'request_id': 'RequestId',
        'split_result': 'SplitResult'
    }

    def __init__(self, request_id=None, split_result=None):  # noqa: E501
        """SplitDocumentResponse - a model defined in Swagger"""  # noqa: E501

        self._request_id = None
        self._split_result = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if split_result is not None:
            self.split_result = split_result

    @property
    def request_id(self):
        """Gets the request_id of this SplitDocumentResponse.  # noqa: E501

        Gets or sets request Id.  # noqa: E501

        :return: The request_id of this SplitDocumentResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this SplitDocumentResponse.

        Gets or sets request Id.  # noqa: E501

        :param request_id: The request_id of this SplitDocumentResponse.  # noqa: E501
        :type: str
        """
        self._request_id = request_id

    @property
    def split_result(self):
        """Gets the split_result of this SplitDocumentResponse.  # noqa: E501

        Gets or sets resylt of splitting document.  # noqa: E501

        :return: The split_result of this SplitDocumentResponse.  # noqa: E501
        :rtype: SplitDocumentResult
        """
        return self._split_result

    @split_result.setter
    def split_result(self, split_result):
        """Sets the split_result of this SplitDocumentResponse.

        Gets or sets resylt of splitting document.  # noqa: E501

        :param split_result: The split_result of this SplitDocumentResponse.  # noqa: E501
        :type: SplitDocumentResult
        """
        self._split_result = split_result


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SplitDocumentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
